pygeodesy.triaxials.triaxial5.Conformal

Package pygeodesy :: Package triaxials :: Module triaxial5 :: Class Conformal |
[frames] | no frames]

# Class Conformal

          object --+
                   |
        named._Named --+
                       |
        named._NamedBase --+
                           |
        named._NamedEnumItem --+
                               |
    bases._UnOrderedTriaxialBase --+
                                   |
          bases._OrderedTriaxialBase --+
                                       |
                                Triaxial --+
                                           |
                                          Conformal

Known Subclasses:
  - ConformalSphere
  - , deprecated.classes.JacobiConformal
  - , deprecated.classes.ConformalTriaxial

This is a Jacobi Conformal projection of a triaxial ellipsoid to a plane where the `X` and `Y` grid lines are straight.

Ellipsoidal coordinates beta and omega are converted to Jacobi Conformal y respectively x separately. Jacobi's coordinates have been multiplied by `sqrt(a**2 - c**2) / (2 * b)` so that the customary results are returned in the case of an ellipsoid of revolution.

Copyright (C) Charles Karney (2014-2024) and licensed under the MIT/X11 License.

Note: This constructor can not be used to specify a sphere, see alternate ConformalSphere.

See Also: Triaxial, C++ class JacobiConformal, Jacobi's conformal projection and Jacobi, C. G. J. Vorlesungen über Dynamik, page 212ff.

Instance Methods
__init__(self, a_triaxial, b=None, c=None, **name) New ordered Triaxial, Triaxial3, Conformal or Conformal3. |
x(self, omega, unit=<class 'pygeodesy.units.Radians'>) Compute a Jacobi Conformal `x` projection. |
xR(self, omega, unit=<class 'pygeodesy.units.Radians'>) Compute a Jacobi Conformal `x` projection. |
xR_(self, somega, comega) Compute a Jacobi Conformal `x` projection. |
xy(self, beta, omega, **unit_name) Compute a Jacobi Conformal `x` and `y` projection. |
xyR2(self, beta, omega, **unit_name) Compute a Jacobi Conformal `x` and `y` projection. |
xyR2_(self, sbeta, cbeta, somega, comega, **name) Compute a Jacobi Conformal `x` and `y` projection. |
y(self, beta, unit=<class 'pygeodesy.units.Radians'>) Compute a Jacobi Conformal `y` projection. |
yR(self, beta, unit=<class 'pygeodesy.units.Radians'>) Compute a Jacobi Conformal `y` projection. |
yR_(self, sbeta, cbeta) Compute a Jacobi Conformal `y` projection. |
Inherited from `Triaxial`: `forwardBetaOmega`, `forwardBetaOmega_`, `forwardCartesian`, `forwardLatLon`, `forwardLatLon_`, `reverseBetaOmega`, `reverseCartesian`, `reverseLatLon` Inherited from `bases._UnOrderedTriaxialBase`: `areaKT`, `area_p`, `hartzell4`, `height4`, `normal3d`, `normal4`, `sideOf`, `toBiaxial`, `toEllipsoid`, `toStr` Inherited from `named._NamedEnumItem`: `unregister` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| xyQ2 Get the Jacobi Conformal quadrant size in `meter` (Vector2Tuple`(x, y)`).
| xyQR2 Get the Jacobi Conformal quadrant size in `Radians` (Conformal2Tuple`(x, y)`).
Inherited from `bases._OrderedTriaxialBase`: `area` Inherited from `bases._UnOrderedTriaxialBase`: `R2`, `R3`, `Rauthalic`, `Rvolumetric`, `a`, `a2`, `abc3`, `areaRG`, `b`, `b2`, `c`, `c2`, `e2ab`, `e2ac`, `e2bc`, `isFlat`, `isOblate`, `isOrdered`, `isProlate`, `isSpherical`, `perimeter4ab`, `perimeter4ac`, `perimeter4bc`, `unOrdered`, `volume` Inherited from `named._NamedEnumItem`: `name` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, a_triaxial, b=None, c=None, **name) (Constructor) |
New ordered Triaxial, Triaxial3, Conformal or Conformal3. Arguments: `a_triaxial` - Largest semi-axis (`scalar`, conventionally in `meter`) or an other Triaxial or Triaxial_ instance. `b` - Middle semi-axis (`meter`, same units as `a`), required if `a_triaxial is scalar`, ignored otherwise. `c` - Smallest semi-axis (`meter`, like `b`). `name` - Optional `name=NN` (`str`). Raises: `TriaxialError` - Semi-axes unordered, spherical or invalid. Overrides: object.__init__ Note: The semi-axes must be ordered as `a >= b >= c > 0` and must be ellipsoidal, `a > c`.

### x (self, omega, unit=<class 'pygeodesy.units.Radians'>) |
Compute a Jacobi Conformal `x` projection. Arguments: `omega` - Ellipsoidal longitude (`Ang` or `unit`). `unit` - Unit of scalar `omega` (or `Degrees`). Returns: The `x` projection (Meter), same units as this triaxial's semi-axes.

### xR (self, omega, unit=<class 'pygeodesy.units.Radians'>) |
Compute a Jacobi Conformal `x` projection. Arguments: `omega` - Ellipsoidal longitude (`Ang` or `unit`). `unit` - Unit of scalar `omega` (or `Degrees`). Returns: The `x` projection (Radians).

### xR_ (self, somega, comega) |
Compute a Jacobi Conformal `x` projection. Arguments: `somega` - Ellipsoidal longitude `sin(omega)` (`scalar`). `comega` - Ellipsoidal longitude `cos(omega)` (`scalar`). Returns: The `x` projection (Radians).

### xy (self, beta, omega, **unit_name) |
Compute a Jacobi Conformal `x` and `y` projection. Arguments: `beta` - Ellipsoidal latitude (`Ang` or `unit`). `omega` - Ellipsoidal longitude (`Ang` or `unit`). `unit_name` - Optional scalar `unit=`Radians and name (`str`), overriding `name="xyR2"`. Returns: A (Vector2Tuple`(x, y)`), both in `Meter`, same units as this triaxial's semi-axes..

### xyR2 (self, beta, omega, **unit_name) |
Compute a Jacobi Conformal `x` and `y` projection. Arguments: `beta` - Ellipsoidal latitude (`Ang` or `unit`). `omega` - Ellipsoidal longitude (`Ang` or `unit`). `unit_name` - Optional scalar `unit=`Radians and name (`str`), overriding `name="xyR2"`. Returns: A Conformal2Tuple`(x, y)`, both in `Radians`.

### xyR2_ (self, sbeta, cbeta, somega, comega, **name) |
Compute a Jacobi Conformal `x` and `y` projection. Arguments: `sbeta` - Ellipsoidal latitude `sin(beta)` (`scalar`). `cbeta` - Ellipsoidal latitude `cos(beta)` (`scalar`). `somega` - Ellipsoidal longitude `sin(omega)` (`scalar`). `comega` - Ellipsoidal longitude `cos(omega)` (`scalar`). `name` - Optional name (`str`), overriding `name="xyR2_"`. Returns: A Conformal2Tuple`(x, y)`.

### y (self, beta, unit=<class 'pygeodesy.units.Radians'>) |
Compute a Jacobi Conformal `y` projection. Arguments: `beta` - Ellipsoidal latitude (`Ang` or `unit`). `unit` - Unit of scalar `beta` (or `Degrees`). Returns: The `y` projection (Meter), same units as this triaxial's semi-axes.

### yR (self, beta, unit=<class 'pygeodesy.units.Radians'>) |
Compute a Jacobi Conformal `y` projection. Arguments: `beta` - Ellipsoidal latitude (`Ang` or `unit`). `unit` - Unit of scalar `beta` (or `Degrees`). Returns: The `y` projection (Radians).

### yR_ (self, sbeta, cbeta) |
Compute a Jacobi Conformal `y` projection. Arguments: `sbeta` - Ellipsoidal latitude `sin(beta)` (`scalar`). `cbeta` - Ellipsoidal latitude `cos(beta)` (`scalar`). Returns: The `y` projection (Radians).

Property Details

### xyQ2 Get the Jacobi Conformal quadrant size in `meter` (Vector2Tuple`(x, y)`). Get method: xyQ2(self) - Get the Jacobi Conformal quadrant size in `meter` (Vector2Tuple`(x, y)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### xyQR2 Get the Jacobi Conformal quadrant size in `Radians` (Conformal2Tuple`(x, y)`). Get method: xyQR2(self) - Get the Jacobi Conformal quadrant size in `Radians` (Conformal2Tuple`(x, y)`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.